@@ -53,6 +53,9 @@ struct _GPdfViewClass {
 
 	void (*zoom_changed) (GPdfView *gpdf_view, gdouble zoom);
 	void (*page_changed) (GPdfView *gpdf_view, gint page);
+
+	void (*close_requested) (GPdfView *gpdf_view);
+	void (*quit_requested)  (GPdfView *gpdf_view);
 };
 
 GType      gpdf_view_get_type       (void);
